import wx
import flags_iso3166 as flags
try:
    from datetime import datetime, timezone
    from zoneinfo import ZoneInfo               # zoneinfo introduced with python3.9
    tzones = True
except Exception as e:
    tzones = False

class MyFrame(wx.Frame):
    def __init__(self, parent, id, title):
        wx.Frame.__init__(self, parent, -1, title)

        self.tree = wx.TreeCtrl(self, wx.ID_ANY,
                                wx.DefaultPosition,
                                wx.DefaultSize,
                                )
        self.tree.SetBackgroundColour('#f1f2f2')
        self.tree.Bind(wx.EVT_TREE_ITEM_ACTIVATED, self.OnTreeCtrl)

        self.choices = {"Australia":"AU","Canada":"CA","Germany":"DE","Spain":"ES","France":"FR",\
                        "United Kingdom":"GB","Italy":"IT","Japan":"JP",\
                        "Russia":"RU","United States of America":"US"}

        self.imagelist = [flags.catalog["Flags"].Bitmap,] # First image for root is Flags


        # Build tree image list
        self.data = sorted([item for item in flags.catalog.keys() if len(item) > 3 and item in self.choices])
        tree_list = []

        self.busy = wx.BusyInfo(
                    wx.BusyInfoFlags()
                   .Parent(self)
                   .Title("300 Entries to be loaded")
                   .Text("Loading flag selections into the Tree\nPlease wait...\n")
                   .Foreground(wx.BLACK)
                   .Background(wx.WHITE)
                   .Transparency(200)
                   )
        with self.busy:
            wx.GetApp().Yield()
            for i in self.data:
                subdata = sorted([item for item in flags.catalog.keys() if len(item) > 3 and item.startswith(i)])
                for i in subdata:
                    tree_list.append(i)
                    iso2, iso3, name, regional = flags.lookup.get(i)
                    self.imagelist.append(wx.BitmapBundle.FromBitmap(flags.catalog[iso2].Bitmap))
        del self.busy
        self.tree.SetImages(self.imagelist)
        self.root = self.tree.AddRoot('Flags', 0)

        # Add items to Tree
        print(tree_list)
        for idx1, flag in enumerate(tree_list):
            if not flags.isregional(flag):
                x = self.tree.AppendItem(self.root, flag, idx1+1)
            else:
                y = self.tree.AppendItem(x, flag, idx1+1)
                iso2 = flags.lookupiso2(flag)                       # Get details of entry
                base_iso2, _, _, _ = flags.lookupbasecountry(iso2)  # get base country of region
                det = flags.details.get(iso2)
                base_det = flags.details.get(base_iso2)             # get details of base country
                if det:
                    capital = det.get('capital')
                    if not capital:
                        capital = base_det.get('capital')
                    tz = det.get('tz')
                    if tzones:                              # Were datetime and zoneinfo imports successful
                        zone = flags.timezone.get(iso2)     # zoneinfo introduced with python3.9
                        if not zone:
                            zone = flags.timezone.get(base_iso2)
                    else:
                        zone = None

                    msg = ""
                    msg += "Capital:\t"+capital
                    msg += "\t| Time Zone: "+tz+" UTC"
                    if zone:
                        zone = zone[0]
                        timenow = datetime.now(ZoneInfo(zone)).strftime('%H:%M:%S - %d %b %Y')
                        if timenow:
                            msg += "\t"+zone+": "+timenow
                    z = self.tree.AppendItem(y, msg)

        self.tree.Expand(self.root)

        self.Show()

    def OnTreeCtrl(self, event):
        item = event.GetItem()
        id = self.tree.GetItemText(item)
        print(id)


#---------------------------------------------------------------------------

class MyApp(wx.App):
    def OnInit(self):
        frame = MyFrame(None, -1, 'Image TreeCtrl')
        frame.Show(True)
        self.SetTopWindow(frame)

        return True

#---------------------------------------------------------------------------

app = MyApp(0)
app.MainLoop()
