import wx
import flags_iso3166 as flags
import time
try:
    from datetime import datetime, timezone
    from zoneinfo import ZoneInfo               # zoneinfo introduced with python3.9
    tzones = True
except Exception as e:
    tzones = False


class Myframe(wx.Frame):
    def __init__(self):
        wx.Frame.__init__(self, None, -1, "Search "+flags.__version__, size=(1300, 500))

        panel = wx.Panel(self)

        panel.SetBackgroundColour('#aaf09e')

        txt1 = wx.StaticText(panel, -1, 'Search')
        self.search = wx.SearchCtrl(panel, -1)
        self.search.ShowSearchButton(True)
        self.search.ShowCancelButton(True)
        txt2 = wx.StaticText(panel, -1, 'Results')

        self.res = wx.ListCtrl(panel, -1, style=wx.LC_REPORT)
        self.res.SetBackgroundColour(wx.Colour('grey85'))
        self.res.SetMinSize((-1, 400))
        self.res.InsertColumn(1, "Country")
        self.res.InsertColumn(2, "Region")
        self.res.InsertColumn(3, "Code")
        self.res.InsertColumn(4, "Local Time")
        self.res.InsertColumn(5, "Capital")
        self.res.InsertColumn(6, "Aka")
        self.res.SetColumnWidth(0, 300)
        self.res.SetColumnWidth(1, 300)
        self.res.SetColumnWidth(3, 200)
        self.res.SetColumnWidth(4, 150)

        sizer1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer1.Add(txt1, 0, wx.ALL, border=5)
        sizer1.Add(self.search, 1, wx.ALL|wx.EXPAND, border=5)
        sizer2 = wx.BoxSizer(wx.HORIZONTAL)
        sizer2.Add(txt2, 0, wx.ALL, border=5)
        sizer2.Add(self.res, 1, wx.ALL|wx.EXPAND, border=5)

        main_sizer = wx.BoxSizer(wx.VERTICAL)
        main_sizer.Add(sizer1, 0, wx.ALL|wx.EXPAND, 10)
        main_sizer.Add(sizer2, 1, wx.ALL|wx.EXPAND, 10)

        panel.SetSizer(main_sizer)
        panel.Layout()

        sizer = wx.BoxSizer(wx.HORIZONTAL)
        sizer.Add(panel, 1, wx.EXPAND, 0)
        self.SetSizer(sizer)
        self.ico = flags.catalog['Flags'].GetIcon()
        self.SetIcon(self.ico)
        self.search.Bind(wx.EVT_SEARCH, self.OnSelect)
        self.Layout()
        self.Show()

    def OnSelect(self, event):
        Choice = event.GetString()
        self.GetData(Choice)

    def GetData(self, choice):
        self.res.DeleteAllItems()

        # pre-load images for the res
        self.imagelist = []
        query = choice.casefold()
        data = [k for k in flags.lookup.keys() if query in k.casefold()]
        if not data:
            self.res.Append(["Nothing Found",'','','',''])
            self.Refresh()
            return
        clean_data = [] # prevent duplicate entries when there's more than 1 hit on a search item
        for i in data:
            iso2, iso3, name, regional = flags.lookup.get(i)
            if iso2 == "Flags":
                continue
            if iso2 not in clean_data:
                clean_data.append(iso2)
        clean_data = sorted(clean_data)

        for i in clean_data:
            self.imagelist.append(wx.BitmapBundle.FromBitmap(flags.catalog[i].Bitmap))

        # Now add the base  country flags to the end of the imagelist
        for i in clean_data:
            b_iso2, b_iso3, base_country, b_regional = flags.lookupbasecountry(i)
            self.imagelist.append(wx.BitmapBundle.FromBitmap(flags.catalog[b_iso2].Bitmap))

        self.res.SetSmallImages(self.imagelist)

        index = 0
        if not clean_data:
            self.res.Append(["Nothing Found",'','','',''])
        for i in clean_data:
            alt = timenow = ''
            det = flags.details.get(i)
            b_iso2, b_iso3, base_country, b_regional = flags.lookupbasecountry(i)
            if tzones:                                      # Were datetime and zoneinfo imports successful
                regzone = flags.timezone.get(i)             # get regional timezone
                if not regzone:
                    regzone = flags.timezone.get(b_iso2)    # no zone get base country timezone
                if regzone:
                    zone = regzone[0]
                    timenow = datetime.now(ZoneInfo(zone)).strftime('%H:%M:%S - %d %b %Y')
            name = flags.lookupname(i)
            capital = det.get('capital', '')
            if not capital:
                base = flags.details.get(b_iso2)
                capital = base.get('capital', '')
            aka = det.get('altname', '')
            self.res.Append([base_country, "", i, timenow, capital, aka])
            self.res.SetItemImage(index, index+len(clean_data))
            self.res.SetItem(index, 1, name, imageId=index)
            index += 1
        self.Refresh()


if __name__ == "__main__":
    App = wx.App()
    Myframe()
    App.MainLoop()
